# The Cloud Package

This package contains functions for integrating with cloud services. Currently, this consists of abstract base classes to support credential management, and interacting with cloud-based object storage.
